import React, { useEffect, useState } from "react";
import Product from "./Product.jsx";
import { Col, Container, Row } from "react-bootstrap";
import "./../styles/ProductGrid.css";
import Config from "../config.js";
import { Link } from "react-router-dom";

export default function ProductGrid({ productData }) {
  const [products, setProducts] = useState([]);

  const fetchProducts = async () => {
    const res = await fetch(`${Config.inventoryUrl}`);
    if (res.ok) {
      const data = await res.json();
      setProducts([...data]);
    }
  };

  useEffect(() => fetchProducts(), []);

  return (
    <div>
      <div className="container mt-3 d-flex justify-content-between align-items-center">
        <h1 id="title" className="text-center">
          Inventory
        </h1>
        <Link type="link" className="btn btn-success" to="/products/new">
          + New Product
        </Link>
      </div>
      <Container id="prod-grid" className="mt-3">
        <Row xs={1} sm={2} md={3} lg={4}>
          {products.map((product) => {
            return (
              <Col key={product.sku}>
                <Product product={product} />
              </Col>
            );
          })}
        </Row>
      </Container>
    </div>

    //uses vanilla bootstrap
    // <div>
    //   	<h1 id="title">Inventory</h1>
    // 	<div className="container" id="prod-grid"  >
    // 	<div className="row row-cols-4">
    // 		{productData.map((product) => {
    // 			return (
    // 					<div className="col" key={product.sku}>
    // 						<Product product={product}/>
    // 					</div>

    // 			)
    // 		})}
    // 		</div>
    // 	</div>
    // </div>
  );
}
